@@ -75,6 +75,12 @@ def template(use_container=False,
 
         mai = Message.Message()
         mai.set_type(mime)
+        
+        if mime == 'text/plain':
+            f = StringIO()
+            HTMLParser(AbstractFormatter(DumbWriter(f))).feed(mail_body)
+            mail_body = f.getvalue()
+            
         mai.set_payload(mail_body)
         mai.add_header("Content-Disposition", "inline", filename=filename)
         mal.append(mai)
